@@ -10,6 +10,7 @@ class DeepWalk(Embedding):
         self.embedding = None;
         self.walk_len = int(args.walk_len)
         self.walks = int(args.number_of_walks)
+        self.dim = int(args.dimension)
         self.walker = args.walker
         self.adj_list = adj_list_reader(args.adj_list)
         self.set_embedding()
@@ -19,14 +20,14 @@ class DeepWalk(Embedding):
         walks = walker(self.adj_list, self.walks, self.walk_len, self.walker)
         
         # word2vec on generated walks
-        self.embedding = word2VecEmbedding(walks)
+        self.embedding = word2VecEmbedding(walks, self.dim)
 
     def get_embedding(self):
         data = {}
         for node in self.adj_list:
             if node in self.embedding.wv:
                 data[node] = self.embedding.wv[node]
-        file_name = "deep_walk_" + self.walker + "_" + str(self.walks) + "_" + str(self.walk_len)
+        file_name = "deep_walk_" + str(self.dim) + "_" + self.walker + "_" + str(self.walks) + "_" + str(self.walk_len)
         export_pickel(data, file_name)
 
 def deep_walk(args):
